pub trait SendUpdateExt {
// Required methods
fn send_update(&mut self, update: &Update) -> Result<()>;
fn send_body(&mut self, body: &[u8]) -> Result<()>;
}Expand description
Extension trait for Axum responses to send Braid updates.
pub trait SendUpdateExt {
// Required methods
fn send_update(&mut self, update: &Update) -> Result<()>;
fn send_body(&mut self, body: &[u8]) -> Result<()>;
}Extension trait for Axum responses to send Braid updates.