Module config

Module config 

Structs

Config

Functions

get_config_path
get_root_dir
get_trash_dir
Get the trash directory for deleted files.
is_binary
Check if a file is binary based on its extension.
skip_file
Check if a path should be skipped during sync.
trash_file
Move a file to the trash directory instead of deleting it.