pub struct DebouncedSyncManager { /* private fields */ }Expand description
Manages debouncing of sync requests to prevent network flooding while maintaining high responsiveness for “sync-as-you-type”.
Implementations
Sourceimpl DebouncedSyncManager
impl DebouncedSyncManager
Sourcepub fn new_placeholder() -> Self
pub fn new_placeholder() -> Self
Create a placeholder manager (used for circular initialization)
Sourcepub fn new(state: DaemonState, debounce_ms: u64) -> Arc<Self>
pub fn new(state: DaemonState, debounce_ms: u64) -> Arc<Self>
Create a new manager and spawn its processing loop.
Sourcepub async fn request_sync(&self, url: String, path: PathBuf)
pub async fn request_sync(&self, url: String, path: PathBuf)
Request a sync for a given URL and path.