Structs
Functions
- get_
config_ path - get_
root_ dir - get_
trash_ dir - Get the trash directory for deleted files.
- is_
binary - Check if a file is binary based on its extension.
- skip_
file - Check if a path should be skipped during sync.
- trash_
file - Move a file to the trash directory instead of deleting it.